local zoomManager = require 'zoom-manager'

function love.load()
  isFullscreen = true
  canvas = love.graphics.newCanvas(320, 180)
  zoomManager:init(canvas)
  canvas:setFilter('nearest', 'nearest')
  love.mouse.setRelativeMode(true)
end

function canvasScaleX() return love.graphics.getWidth() / canvas:getWidth() end
function canvasScaleY() return love.graphics.getHeight() / canvas:getHeight() end

function love.update(dt)
  zoomManager:update(dt)
end

function love.draw()
  love.graphics.setCanvas(canvas)
  love.graphics.clear(0, 0, 0)

  love.graphics.setColor(1, 1, 1)
  zoomManager:draw(canvas)

  love.graphics.setColor(1, 1, 1, 0.5)
  love.graphics.print(
    'FPS:' .. love.timer.getFPS() ..
    '\nzoom: ' .. zoomManager.zoom
  )

  love.graphics.setCanvas()
  love.graphics.setColor(1, 1, 1)
  love.graphics.draw(canvas, 0, 0, 0, canvasScaleX(), canvasScaleY())
end

function love.keypressed(k)
  if k == 'escape' then
    love.event.quit()
  elseif love.keyboard.isDown('lctrl') then
    if k == 'f' then
      isFullscreen = not isFullscreen
      love.window.setMode(320 * 3, 180 * 3, {
        x = nil,
        y = nil,
        fullscreen = isFullscreen
      })
    end
  end
end

function love.mousemoved(x, y)
  zoomManager:setViewport(x, y, {
    w = canvas:getWidth(),
    h = canvas:getHeight(),
    canvasScaleX = canvasScaleX(),
    canvasScaleY = canvasScaleY(),
  })
end

function love.wheelmoved(x, y)
  if y > 0 then
    zoomManager:changeZoom(1)
  elseif y < 0 then
    zoomManager:changeZoom(-1)
  end
end
