local flux = require 'lib/flux'

local zoomManager = {
  zoomIndex = 1,
  zoomValues = {
    1, 2, 4
  },
  animationDelay = 0.5,
  originLimit = 0.25
}

function zoomManager:init(canvas)
  self.bg = love.graphics.newImage('test.jpg')
  self.imgW, self.imgH = self.bg:getWidth(), self.bg:getHeight()
  self.zoom = 1
  self.imgX, self.imgY = 0, 0

  self.viewport = {
    originX = self.imgW / 2,
    originY = self.imgH / 2,
    x = math.floor(canvas:getWidth() / 2),
    y = math.floor(canvas:getHeight() / 2),
  }
  return self
end

function zoomManager:update(dt)
  flux.update(dt)
end

function zoomManager:setViewport(x, y, data)
  x = x / data.canvasScaleX
  y = y / data.canvasScaleY
  flux.to(self.viewport, self.animationDelay, {
    originX = (self.imgW * (x / data.w)),
    originY = (self.imgH * (y / data.h)),
    x = x,
    y = y
  })
end


function zoomManager:changeZoom(value)
  self.zoomIndex = self.zoomIndex + value

  if self.zoomIndex > #self.zoomValues then
    self.zoomIndex = #self.zoomValues
    return
  end
  if self.zoomIndex < 1 then
    self.zoomIndex = 1
    return
  end

  local newZoom = self.zoomValues[self.zoomIndex]
  if newZoom == 1 then
    flux.to(self, self.animationDelay, { imgX = 0, imgY = 0 })
  end

  flux.to(self, self.animationDelay, { zoom = newZoom })
end

function zoomManager:draw(canvas)
  love.graphics.draw(
    self.bg,
    self.viewport.x,
    self.viewport.y,
    0,
    (canvas:getWidth() / self.imgW) * self.zoom,
    (canvas:getHeight() / self.imgH) * self.zoom,
    self.viewport.originX,
    self.viewport.originY
  )
end

return zoomManager
